from optipy import _get_version_list, _get_version

def getVersionList():
    return _get_version_list.start()

def getVersion(mc_version:str=None):
    if not mc_version: raise Exception("'mc_version' is Required! Missing Minecraft Version.")
    return _get_version.start(mc_version)


from bs4 import BeautifulSoup
from urllib.parse import urlparse, parse_qs
import requests
from pprint import pprint

def start(mc_version):
    DATA = {}

    url = "https://www.optifine.net/downloads"
    response = requests.get(url)

    soup = BeautifulSoup(response.text, "html.parser")

    h2 = soup.find("h2", string=f'Minecraft {mc_version}')
    if not h2: return None
    mc_version = f'{h2.text.replace("Minecraft ","")}'

    table_element = h2.find_next("table", {"class": "downloadTable"})
    
    if table_element:
        tr_elements = table_element.find_all("tr",{"class": "downloadLine"})
        if not tr_elements: return None
        item = []
        for tr in tr_elements:
            title = tr.find("td", class_="colFile").text
            date = tr.find("td", class_="colDate").text
            forge = tr.find("td", class_="colForge").text
            mirror = tr.find("td", class_="colMirror")
            mirror_link = mirror.find("a").get("href")
            parsed_link = urlparse(mirror_link)
            
            
            # Parse the query string into a dictionary
            args = parse_qs(parsed_link.query)

            # Get the value of 'f'
            f_value = args["f"][0]
            url = f"https://optifine.net/download?f={f_value}"
            item.append({
                "title": title,
                "date": date,
                "forge": forge,
                "url": url,
            })
        DATA[mc_version] = item
    return DATA

if __name__ == "__main__":
    DATA = start(mc_version="1.12.2")
    pprint(DATA, sort_dicts=False)



from setuptools import setup, find_packages

classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Information Technology',
  'Operating System :: OS Independent',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]

with open('./requirements.txt', "r", encoding='utf-16') as f:
  required_packages = f.read().splitlines()

setup(
  name='optipy',
  version='2.0.2',
  description='Web Scraping API for getting Optifine VersionsList/Versions/Download-URL.',
  long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
  long_description_content_type='text/markdown',
  url='https://github.com/GoodDay360/OptiPy',  
  author='GoodDay360',
  author_email='istartgame31@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords=['optifine','api','optifine_api'], 
  packages=find_packages(exclude=["dist","git","optipy.egg-info","venv"]),
  install_requires=required_packages,
  python_requires='>=3.6',
)


from bs4 import BeautifulSoup
from urllib.parse import urlparse, parse_qs
import requests
from pprint import pprint

def start():
    DATA = {}

    url = "https://www.optifine.net/downloads"
    response = requests.get(url)

    soup = BeautifulSoup(response.text, "html.parser")

    h2_elements = soup.find_all("h2")
    if not h2_elements: return None
    for h2 in h2_elements:
        mc_version = f'{h2.text.replace("Minecraft ","")}'

        # Find the next 'table' element after 'h2' element
        table_element = h2.find_next("table", {"class": "downloadTable"})

        if table_element:
            tr_elements = table_element.find_all("tr",{"class": "downloadLine"})
            if not tr_elements: return None
            item = []
            for tr in tr_elements:
                title = tr.find("td", class_="colFile").text
                date = tr.find("td", class_="colDate").text
                forge = tr.find("td", class_="colForge").text
                mirror = tr.find("td", class_="colMirror")
                mirror_link = mirror.find("a").get("href")
                parsed_link = urlparse(mirror_link)
                
                
                # Parse the query string into a dictionary
                args = parse_qs(parsed_link.query)

                # Get the value of 'f'
                f_value = args["f"][0]
                url = f"https://optifine.net/download?f={f_value}"
                item.append({
                    "title": title,
                    "date": date,
                    "forge": forge,
                    "url": url,
                })
            DATA[mc_version] = item
    return DATA

if __name__ == "__main__":
    DATA = start()
    pprint(DATA, sort_dicts=False)
